"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parsepdf = exports.render = void 0;
const pdfjs_dist_1 = require("pdfjs-dist");
const isTextItem = (item) => {
    return "transform" in item;
};
/**
 * Renders a pdf.js page to text
 * @param page The pdf.js page to render
 * @returns The text content of the page
 */
const render = async (page) => {
    const content = await page.getTextContent();
    let lastYPosition;
    let text = "";
    for (const item of content.items) {
        if (!isTextItem(item)) {
            continue;
        }
        const textYPosition = item.transform[5];
        if (lastYPosition == textYPosition || !lastYPosition) {
            text += item.str;
        }
        else {
            text += "\n" + item.str;
        }
        lastYPosition = textYPosition;
    }
    return text;
};
exports.render = render;
/**
 * Parses a PDF
 * @param buffer The buffer data from of the pdf
 * @returns The parsed data from the pdf
 */
const parsepdf = async (buffer) => {
    const document = await (0, pdfjs_dist_1.getDocument)(buffer).promise;
    const { metadata, info } = await document.getMetadata();
    const tasks = Array(document.numPages)
        .fill(0)
        .map(async (_, i) => {
        const page = await document.getPage(i + 1);
        return (0, exports.render)(page);
    });
    const pages = await Promise.all(tasks);
    await document.destroy();
    return {
        metadata,
        info,
        pages
    };
};
exports.parsepdf = parsepdf;
